Utils class
Utils 工具类
Constructors
- Utils()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
capitalize(
String val) → dynamic - 首字母大写
-
checkFieldIsEmpty(
dynamic fields) → dynamic - 字段校验并提示
-
debounce(
Function? fn, [int delay = 1000, dynamic immediate = true]) → void Function()? - 函数防抖
-
indexWhere(
List list, bool condition(dynamic), {bool needReset = false}) → int - 查找索引
-
isNotNullOrBlank(
dynamic val) → dynamic - 数据不为空
-
isNullOrBlank(
dynamic val) → dynamic - 数据为空
-
removeDecimal(
String val) → dynamic - 去除小数点
-
tryParse<
T> (dynamic val) → dynamic - 检查数字或字符串